@@ -2,7 +2,7 @@ use strict;
 use warnings FATAL => 'all';
 
 package Apache::SWIT::DB::Base;
-use base 'Class::DBI::Pg';
+use base 'Class::DBI::Pg::More';
 use Apache::SWIT::DB::Connection;
 
 $Class::DBI::Weaken_Is_Available = 0;
