@@ -7,8 +7,9 @@ use File::Slurp;
 
 sub location_section_contents {
 	my ($self, $res, $n, $v) = @_;
-	my $t = $v->{template};
-	return $t ? "\tPerlSetVar SWITTemplate \@ServerRoot\@/$t\n" : "";
+	my $t = $v->{template} or return "";
+	return "\tPerlSetVar SWITIncludePath \@ServerRoot\@\t\n"
+		. "PerlSetVar SWITTemplate $t\n";
 }
 
 sub httpd_conf_start {
