@@ -8,6 +8,7 @@ use Apache::SWIT::Maker::Manifest;
 
 sub dump_page_entry {
 	my ($self, $res, $v) = @_;
+	return $v unless $v->{entry_points};
 	my $rc = Apache::SWIT::Maker::Config->instance->root_class;
 	my $tt_file = $v->{entry_points}->{r}->{template};
 	$v->{file} = read_file($tt_file);
@@ -18,6 +19,7 @@ sub dump_page_entry {
 
 sub install_page_entry {
 	my ($self, $res, $v, $module) = @_;
+	return $v unless $v->{entry_points};
 	my $lcm = lc($module);
 	my $tt_file = $v->{entry_points}->{r}->{template} =
 		"templates/$lcm/" . $v->{entry_points}->{r}->{template};
@@ -27,11 +29,4 @@ sub install_page_entry {
 	return $v;
 }
 
-sub httpd_conf_start {
-	my ($self, $res) = @_;
-	my $sc = Apache::SWIT::Maker::Config->instance->session_class;
-	$res =~ s/$sc/T::$sc/g;
-	return $res;
-}
-
 1;
