@@ -16,7 +16,7 @@ use base qw(Apache::SWIT::HTPage);
 
 sub ht_root_class { return __PACKAGE__ . '::Root'; }
 
-sub on_inheritance_end {
+sub swit_startup {
 	my $class = shift;
 	my $rc = $class->ht_root_class;
 	[% FOREACH fields_v %]
